public inbox for gcc-cvs@sourceware.org
help / color / mirror / Atom feed
* [gcc r11-3483] Fix handling of clobbers in ipa-modref.c
@ 2020-09-26 16:41 Jan Hubicka
  0 siblings, 0 replies; only message in thread
From: Jan Hubicka @ 2020-09-26 16:41 UTC (permalink / raw)
  To: gcc-cvs

https://gcc.gnu.org/g:3991912e260d68f0da8d3711b5258c3a3009dc4c

commit r11-3483-g3991912e260d68f0da8d3711b5258c3a3009dc4c
Author: Jan Hubicka <jh@suse.cz>
Date:   Sat Sep 26 18:40:50 2020 +0200

    Fix handling of clobbers in ipa-modref.c
    
            * ipa-modref.c (analyze_stmt): Do not skip clobbers in early pass.
            * ipa-pure-const.c (analyze_stmt): Update comment.

Diff:
---
 gcc/ipa-modref.c     | 11 +++++++----
 gcc/ipa-pure-const.c |  2 ++
 2 files changed, 9 insertions(+), 4 deletions(-)

diff --git a/gcc/ipa-pure-const.c b/gcc/ipa-pure-const.c
index bdbccd010dc..1af3206056e 100644
--- a/gcc/ipa-pure-const.c
+++ b/gcc/ipa-pure-const.c
@@ -742,6 +742,8 @@ check_stmt (gimple_stmt_iterator *gsip, funct_state local, bool ipa)
   /* Do consider clobber as side effects before IPA, so we rather inline
      C++ destructors and keep clobber semantics than eliminate them.
 
+     Similar logic is in ipa-modref.
+
      TODO: We may get smarter during early optimizations on these and let
      functions containing only clobbers to be optimized more.  This is a common
      case of C++ destructors.  */


^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2020-09-26 16:41 UTC | newest]

Thread overview: (only message) (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2020-09-26 16:41 [gcc r11-3483] Fix handling of clobbers in ipa-modref.c Jan Hubicka

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).
diff --git a/gcc/ipa-modref.c b/gcc/ipa-modref.c
index 73a7900883a..728c6c1523d 100644
--- a/gcc/ipa-modref.c
+++ b/gcc/ipa-modref.c
@@ -676,13 +676,16 @@ static bool
 analyze_stmt (modref_summary *summary, gimple *stmt, bool ipa,
 	      vec <gimple *> *recursive_calls)
 {
-  /* There is no need to record clobbers.  */
-  if (gimple_clobber_p (stmt))
+  /* In general we can not ignore clobbers because they are barries for code
+     motion, however after inlining it is safe to do becuase local optimization
+     passes do not consider clobbers from other functions.
+     Similar logic is in ipa-pure-consts.  */
+  if ((ipa || cfun->after_inlining) && gimple_clobber_p (stmt))
     return true;
+
   /* Analyze all loads and stores in STMT.  */
   walk_stmt_load_store_ops (stmt, summary,
 			    analyze_load, analyze_store);
-  /* or call analyze_load_ipa, analyze_store_ipa */
 
   switch (gimple_code (stmt))
    {
@@ -705,7 +708,7 @@ analyze_stmt (modref_summary *summary, gimple *stmt, bool ipa,
    }
 }
 
 /* Analyze function F.  IPA indicates whether we're running in tree mode (false)
    or the IPA mode (true).  */
 
 static void
@@ -705,7 +708,7 @@ analyze_stmt (modref_summary *summary, gimple *stmt, bool ipa,
 }
 
-/* Analyze function F.  IPA indicates whether we're running in tree mode (false)
+/* Analyze function F.  IPA indicates whether we're running in local mode (false)
    or the IPA mode (true).  */
 